@@ -199,7 +199,7 @@ class EditItemsDlg(EditItemsFrm):
             return
         
         item = self.selected[0].item
-        dlg = PreviewItemDlg(item.q, item.a, item.cat.name, self)
+        dlg = PreviewItemDlg(item, self)
         
         dlg.exec_loop()
         
@@ -235,7 +235,7 @@ class EditItemsDlg(EditItemsFrm):
         else:
             for list_item in self.selected:
                 i = list_item.item
-                new_list_item = add_new_item(i.grade,i.a,i.q,i.cat.name,\
+                new_list_item = add_new_item(0,i.a,i.q,i.cat.name,\
                                              i.id+'.inv')
                 ListItem(self.item_list, new_list_item)
 
@@ -336,7 +336,7 @@ class EditItemsDlg(EditItemsFrm):
         if len(to_find) == 0:
             return
         
-        if self.to_find.text() != self.last_search_str:
+        if to_find != self.last_search_str:
             
             self.last_search_str = to_find
             
@@ -381,6 +381,7 @@ class EditItemsDlg(EditItemsFrm):
                                     
         if f:
             self.find_button.setText(self.trUtf8("&Find again"))
+            self.find_button.setDefault(1)
             self.item_list.setFocus()
             self.item_list.clearSelection()
             self.item_list.ensureItemVisible(f)
@@ -400,6 +401,8 @@ class EditItemsDlg(EditItemsFrm):
     
     def keyPressEvent(self, e):
         if e.key() == Qt.Key_F3 or \
+           e.key() == Qt.Key_Enter or \
+           e.key() == Qt.Key_Return or \
           (e.key() == QKeySequence(self.trUtf8("F")) and e.state() == \
                                                           Qt.ControlButton):
             self.find()
