@@ -157,7 +157,8 @@ Vytvářím tmp soubor.</translation>
     <message>
         <source>More info: http://mnemosyne-proj.org
 </source>
-        <translation type="unfinished"></translation>
+        <translation>Více informací: http://mnemosyne-proj.org
+</translation>
     </message>
 </context>
 <context>
@@ -402,7 +403,7 @@ Vytvářím tmp soubor.</translation>
     </message>
     <message>
         <source>Preview</source>
-        <translation type="unfinished"></translation>
+        <translation>Náhled</translation>
     </message>
 </context>
 <context>
@@ -504,7 +505,7 @@ Vytvářím tmp soubor.</translation>
     </message>
     <message>
         <source>Number of grade 0 cards to learn at once:</source>
-        <translation>Počet karet s hodnocením 0 pro okamžité učení:</translation>
+        <translation type="obsolete">Počet karet s hodnocením 0 pro okamžité učení:</translation>
     </message>
     <message>
         <source>Note: this is NOT the number of grade 0 cards you want to memorise *per day*</source>
@@ -524,6 +525,10 @@ Vytvářím tmp soubor.</translation>
     </message>
     <message>
         <source>Learn new cards in random order</source>
+        <translation>Učit se nové kartičky v náhodném pořadí</translation>
+    </message>
+    <message>
+        <source>Number of grade 0 cards to hold in your hand:</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -706,10 +711,6 @@ takže by jste potom měl(a) provést </translation>
         <source>&amp;Find</source>
         <translation>&amp;Hledat</translation>
     </message>
-    <message>
-        <source>Alt+F</source>
-        <translation type="obsolete"></translation>
-    </message>
 </context>
 <context>
     <name>EditItemsFrm</name>
@@ -747,7 +748,7 @@ takže by jste potom měl(a) provést </translation>
     </message>
     <message>
         <source>Alt+F</source>
-        <translation type="unfinished"></translation>
+        <translation>Alt+F</translation>
     </message>
 </context>
 <context>
@@ -954,7 +955,7 @@ takže by jste potom měl(a) provést </translation>
     </message>
     <message>
         <source>Show answer</source>
-        <translation type="unfinished">Ukázat odpověď</translation>
+        <translation>Ukázat odpověď</translation>
     </message>
 </context>
 <context>
@@ -1368,7 +1369,7 @@ O ukládání vaší práce se starat nemusíte, to já budu dělat automaticky.
 &lt;p&gt;
 Nejlepších výsledků dosáhnete, pokud budete opakovat každý den. Budu ale dělat, co je v mých silách i pokud opakování odložíte nebo se rozhodnete naučit se něco navíc.
 &lt;p&gt;
-Další dokumentace viz. http://www.mnemosyne-proj.sourceforge.net.
+Další dokumentace viz. http://mnemosyne-proj.org
 &lt;p&gt;
 Šťastné učení!</translation>
     </message>
@@ -1422,7 +1423,7 @@ Další dokumentace viz. http://www.mnemosyne-proj.sourceforge.net.
         <source>Scheduled cards for the next days:
 
 </source>
-        <translation>Karty naplánované na následující dny:
+        <translation type="obsolete">Karty naplánované na následující dny:
         
 </translation>
     </message>
@@ -1448,31 +1449,37 @@ Další dokumentace viz. http://www.mnemosyne-proj.sourceforge.net.
     </message>
     <message>
         <source>No current card.</source>
-        <translation type="unfinished"></translation>
+        <translation>Není žádná aktuální karta</translation>
     </message>
     <message>
         <source>Grade:</source>
-        <translation type="unfinished">Hodnocení:</translation>
+        <translation>Hodnocení:</translation>
     </message>
     <message>
         <source>Easiness:</source>
-        <translation type="unfinished">Jednoduchost:</translation>
+        <translation>Jednoduchost:</translation>
     </message>
     <message>
         <source>Repetitions:</source>
-        <translation type="unfinished">Opakování:</translation>
+        <translation>Opakování:</translation>
     </message>
     <message>
         <source>Lapses:</source>
-        <translation type="unfinished">Zapomenutí:</translation>
+        <translation>Zapomenutí:</translation>
     </message>
     <message>
         <source>Days since last repetition:</source>
-        <translation type="unfinished">Dnů od posledního opakování:</translation>
+        <translation>Dnů od posledního opakování:</translation>
     </message>
     <message>
         <source>Days until next repetition:</source>
-        <translation type="unfinished">Dnů do dalšího opakování:</translation>
+        <translation>Dnů do dalšího opakování:</translation>
+    </message>
+    <message>
+        <source>Scheduled cards for next week:
+
+</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -1507,7 +1514,7 @@ Další dokumentace viz. http://www.mnemosyne-proj.sourceforge.net.
     </message>
     <message>
         <source>Current card</source>
-        <translation type="unfinished"></translation>
+        <translation>Aktuální karta</translation>
     </message>
 </context>
 <context>
@@ -1586,7 +1593,7 @@ Další dokumentace viz. http://www.mnemosyne-proj.sourceforge.net.
     </message>
     <message>
         <source>The best way to backup your data is to copy your .mnemosyne directory (if you follow the recommended procedure to keep all your files there) and move it to a different drive. Mnemosyne keeps automatic XML-based backups in .mnemosyne/backups, but that won&apos;t help you if that drive dies... </source>
-        <translation type="unfinished">Nejlepší cestou k zálohování vašich dat je kopírovat váš .mnemosyne adresář (za předpokladu, že se držíte doporučení a máte všechny soubory v tomto adresáři) na jiný disk. Mnemosyne sice automaticky vytváří XML zálohy v .mnemosyne/backups, to vám ale při poruše disku nebude moc platné. </translation>
+        <translation>Nejlepší cestou k zálohování vašich dat je kopírovat váš .mnemosyne adresář (za předpokladu, že se držíte doporučení a máte všechny soubory v tomto adresáři) na jiný disk. Mnemosyne sice automaticky vytváří XML zálohy v .mnemosyne/backups, to vám ale při poruše disku nebude moc platné. </translation>
     </message>
     <message>
         <source>You can run Mnemosyne from a USB key. Copy C:\Program Files\Mnemosyne to your USB key, and then copy the .mnemosyne directory from your home directory to inside the Mnemosyne directory on the USB key.</source>
@@ -1602,11 +1609,11 @@ Další dokumentace viz. http://www.mnemosyne-proj.sourceforge.net.
     </message>
     <message>
         <source>If you want more fine-grained control over LaTeX&apos;s behaviour, see the explanation of the &lt;$$&gt;...&lt;/$$&gt; and &lt;latex&gt;...&lt;/latex&gt; tags on Mnemosyne&apos;s website.</source>
-        <translation type="unfinished">Více informací o LaTeXu v Mnemosyne najdete zde http://mnemosyne-proj.sourceforge.net/faq.php</translation>
+        <translation>Více informací o LaTeXu v Mnemosyne najdete na www stránkách Mnemosyne.</translation>
     </message>
     <message>
         <source>Advanced users can customise more of Mnemosyne by editing the config.py file in their .mnemosyne directory. They can also install plugins to customise Mnemosyne even further.</source>
-        <translation>Pokročilí uživatelé si mohou nastavit Mnemosyne editací souboru config.py ve .mnemosyne adresáři. Je možné také instalovat pluginy, které dále mění chování Mnemosyne.</translation>
+        <translation>Pokročilí uživatelé si mohou nastavit Mnemosyne editací souboru config.py v .mnemosyne adresáři. Je možné také instalovat pluginy, které dále mění chování Mnemosyne.</translation>
     </message>
 </context>
 <context>
