@@ -507,7 +507,7 @@ Erstelle temporäre Datei.</translation>
     </message>
     <message>
         <source>Number of grade 0 cards to learn at once:</source>
-        <translation>Kartenanzahl mit der Bewertung 0, die auf einmal gelernt werden:</translation>
+        <translation type="obsolete">Kartenanzahl mit der Bewertung 0, die auf einmal gelernt werden:</translation>
     </message>
     <message>
         <source>Note: this is NOT the number of grade 0 cards you want to memorise *per day*</source>
@@ -529,6 +529,10 @@ Erstelle temporäre Datei.</translation>
         <source>Learn new cards in random order</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Number of grade 0 cards to hold in your hand:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditItemFrm</name>
@@ -1449,7 +1453,7 @@ Viel Spass und Erfolg!</translation>
         <source>Scheduled cards for the next days:
 
 </source>
-        <translation>Vorgemerkte Karten für die nächsten Tage:
+        <translation type="obsolete">Vorgemerkte Karten für die nächsten Tage:
 
 </translation>
     </message>
@@ -1501,6 +1505,12 @@ Viel Spass und Erfolg!</translation>
         <source>Days until next repetition:</source>
         <translation type="unfinished">Tage bis zur nächsten Wiederholung:</translation>
     </message>
+    <message>
+        <source>Scheduled cards for next week:
+
+</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>StatisticsFrm</name>
