@@ -387,7 +387,7 @@ Creando un archivo temporal.</translation>
     </message>
     <message>
         <source>&amp;Preview</source>
-        <translation>&amp;Previsualizar</translation>
+        <translation type="obsolete">&amp;Previsualizar</translation>
     </message>
     <message>
         <source>Ctrl+P</source>
@@ -401,6 +401,10 @@ Creando un archivo temporal.</translation>
         <source>Alt+X</source>
         <translation>Alt+S</translation>
     </message>
+    <message>
+        <source>Preview</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ChangeCategoryFrm</name>
@@ -501,7 +505,7 @@ Creando un archivo temporal.</translation>
     </message>
     <message>
         <source>Number of grade 0 cards to learn at once:</source>
-        <translation>Número de tarjetas con puntuación 0 a aprender de una vez:</translation>
+        <translation type="obsolete">Número de tarjetas con puntuación 0 a aprender de una vez:</translation>
     </message>
     <message>
         <source>Note: this is NOT the number of grade 0 cards you want to memorise *per day*</source>
@@ -519,6 +523,14 @@ Creando un archivo temporal.</translation>
         <source>&amp;Cancel</source>
         <translation>&amp;Cancelar</translation>
     </message>
+    <message>
+        <source>Learn new cards in random order</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Number of grade 0 cards to hold in your hand:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditItemFrm</name>
@@ -699,6 +711,10 @@ Tal vez desee ejecutar </translation>
         <source>&amp;Find</source>
         <translation>&amp;Buscar</translation>
     </message>
+    <message>
+        <source>Alt+F</source>
+        <translation type="obsolete"></translation>
+    </message>
 </context>
 <context>
     <name>EditItemsFrm</name>
@@ -734,6 +750,10 @@ Tal vez desee ejecutar </translation>
         <source>Alt+X</source>
         <translation>Alt+S</translation>
     </message>
+    <message>
+        <source>Alt+F</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ExportDlg</name>
@@ -903,7 +923,7 @@ Tal vez desee ejecutar </translation>
     </message>
     <message>
         <source>Show &amp;answer</source>
-        <translation>Mostrar &amp;respuesta</translation>
+        <translation type="obsolete">Mostrar &amp;respuesta</translation>
     </message>
     <message>
         <source>Learn ahead of schedule</source>
@@ -937,6 +957,10 @@ Tal vez desee ejecutar </translation>
         <source> days.</source>
         <translation type="unfinished"> días.</translation>
     </message>
+    <message>
+        <source>Show answer</source>
+        <translation type="unfinished">Mostrar respuesta</translation>
+    </message>
 </context>
 <context>
     <name>MainFrm</name>
@@ -1425,7 +1449,7 @@ Puede obtener más información en http://www.mnemosyne-proj.sourceforge.net.
         <source>Scheduled cards for the next days:
 
 </source>
-        <translation>Tarjetas planificadas para los próximos días:
+        <translation type="obsolete">Tarjetas planificadas para los próximos días:
 
 </translation>
     </message>
@@ -1449,6 +1473,40 @@ Puede obtener más información en http://www.mnemosyne-proj.sourceforge.net.
         <source>Grade</source>
         <translation>Puntuación</translation>
     </message>
+    <message>
+        <source>No current card.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Grade:</source>
+        <translation type="unfinished">Puntuación:</translation>
+    </message>
+    <message>
+        <source>Easiness:</source>
+        <translation type="unfinished">Facilidad:</translation>
+    </message>
+    <message>
+        <source>Repetitions:</source>
+        <translation type="unfinished">Repeticiones:</translation>
+    </message>
+    <message>
+        <source>Lapses:</source>
+        <translation type="unfinished">Olvidos:</translation>
+    </message>
+    <message>
+        <source>Days since last repetition:</source>
+        <translation type="unfinished">Días desde la última repetición:</translation>
+    </message>
+    <message>
+        <source>Days until next repetition:</source>
+        <translation type="unfinished">Días hasta la próxima repetición:</translation>
+    </message>
+    <message>
+        <source>Scheduled cards for next week:
+
+</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>StatisticsFrm</name>
@@ -1480,6 +1538,10 @@ Puede obtener más información en http://www.mnemosyne-proj.sourceforge.net.
         <source>&amp;OK</source>
         <translation>&amp;Aceptar</translation>
     </message>
+    <message>
+        <source>Current card</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>TipDlg</name>
