@@ -494,7 +494,7 @@ Creating tmp file.</source>
     </message>
     <message>
         <source>Number of grade 0 cards to learn at once:</source>
-        <translation>تعداد کارت‌های مرتبه »۰« برای یاد گرفتن با هم:</translation>
+        <translation type="obsolete">تعداد کارت‌های مرتبه »۰« برای یاد گرفتن با هم:</translation>
     </message>
     <message>
         <source>Note: this is NOT the number of grade 0 cards you want to memorise *per day*</source>
@@ -516,6 +516,10 @@ Creating tmp file.</source>
         <source>Learn new cards in random order</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Number of grade 0 cards to hold in your hand:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditItemFrm</name>
@@ -1386,7 +1390,7 @@ Happy learning!</source>
         <source>Scheduled cards for the next days:
 
 </source>
-        <translation>کارت‌های برنامه‌ریزی شده برای روزهای بعد:</translation>
+        <translation type="obsolete">کارت‌های برنامه‌ریزی شده برای روزهای بعد:</translation>
     </message>
     <message>
         <source>In</source>
@@ -1435,6 +1439,12 @@ Happy learning!</source>
         <source>Days until next repetition:</source>
         <translation type="unfinished">روزهای قبل از مرور بعدی:</translation>
     </message>
+    <message>
+        <source>Scheduled cards for next week:
+
+</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>StatisticsFrm</name>
