@@ -508,7 +508,7 @@ Création d&apos;un fichier tmp.</translation>
     </message>
     <message>
         <source>Number of grade 0 cards to learn at once:</source>
-        <translation>Nombres de cartes de note 0 à apprendre à la fois :</translation>
+        <translation type="obsolete">Nombres de cartes de note 0 à apprendre à la fois :</translation>
     </message>
     <message>
         <source>Note: this is NOT the number of grade 0 cards you want to memorise *per day*</source>
@@ -530,6 +530,10 @@ Création d&apos;un fichier tmp.</translation>
         <source>Learn new cards in random order</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Number of grade 0 cards to hold in your hand:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditItemFrm</name>
@@ -1422,7 +1426,7 @@ Joyeux apprentissage!</translation>
         <source>Scheduled cards for the next days:
 
 </source>
-        <translation>Cartes planifiées pour les jours suivants :
+        <translation type="obsolete">Cartes planifiées pour les jours suivants :
 
 </translation>
     </message>
@@ -1474,6 +1478,12 @@ Joyeux apprentissage!</translation>
         <source>Days until next repetition:</source>
         <translation type="unfinished">Jours jusqu&apos;à la prochaine répétition :</translation>
     </message>
+    <message>
+        <source>Scheduled cards for next week:
+
+</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>StatisticsFrm</name>
