@@ -508,7 +508,7 @@ Ik creëer tmp bestand.</translation>
     </message>
     <message>
         <source>Number of grade 0 cards to learn at once:</source>
-        <translation>Aantal 0 beoordelingskaarten in eenmaal te leren:</translation>
+        <translation type="obsolete">Aantal 0 beoordelingskaarten in eenmaal te leren:</translation>
     </message>
     <message>
         <source>Note: this is NOT the number of grade 0 cards you want to memorise *per day*</source>
@@ -530,6 +530,10 @@ Ik creëer tmp bestand.</translation>
         <source>Learn new cards in random order</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Number of grade 0 cards to hold in your hand:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditItemFrm</name>
@@ -1450,7 +1454,7 @@ Veel plezier met leren!</translation>
         <source>Scheduled cards for the next days:
 
 </source>
-        <translation>Geroosterde kaarten voor de volgende dagen:
+        <translation type="obsolete">Geroosterde kaarten voor de volgende dagen:
 
 </translation>
     </message>
@@ -1502,6 +1506,12 @@ Veel plezier met leren!</translation>
         <source>Days until next repetition:</source>
         <translation type="unfinished">Dagen tot volgende bevraging:</translation>
     </message>
+    <message>
+        <source>Scheduled cards for next week:
+
+</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>StatisticsFrm</name>
