@@ -388,7 +388,7 @@ Creating tmp file.</source>
     </message>
     <message>
         <source>&amp;Preview</source>
-        <translation>預覽(&amp;P)</translation>
+        <translation type="obsolete">預覽(&amp;P)</translation>
     </message>
     <message>
         <source>Ctrl+P</source>
@@ -402,6 +402,10 @@ Creating tmp file.</source>
         <source>Alt+X</source>
         <translation>Alt+X</translation>
     </message>
+    <message>
+        <source>Preview</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ChangeCategoryFrm</name>
@@ -502,7 +506,7 @@ Creating tmp file.</source>
     </message>
     <message>
         <source>Number of grade 0 cards to learn at once:</source>
-        <translation>一次學習0分卡片數量：</translation>
+        <translation type="obsolete">一次學習0分卡片數量：</translation>
     </message>
     <message>
         <source>Note: this is NOT the number of grade 0 cards you want to memorise *per day*</source>
@@ -520,6 +524,14 @@ Creating tmp file.</source>
         <source>&amp;Cancel</source>
         <translation>取消(&amp;C)</translation>
     </message>
+    <message>
+        <source>Learn new cards in random order</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Number of grade 0 cards to hold in your hand:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditItemFrm</name>
@@ -699,6 +711,10 @@ so you might want to run </source>
         <source>&amp;Find</source>
         <translation>尋找(&amp;F)</translation>
     </message>
+    <message>
+        <source>Alt+F</source>
+        <translation type="obsolete"></translation>
+    </message>
 </context>
 <context>
     <name>EditItemsFrm</name>
@@ -734,6 +750,10 @@ so you might want to run </source>
         <source>Alt+X</source>
         <translation>Alt+X</translation>
     </message>
+    <message>
+        <source>Alt+F</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ExportDlg</name>
@@ -911,7 +931,7 @@ so you might want to run </source>
     </message>
     <message>
         <source>Show &amp;answer</source>
-        <translation>察看答案(&amp;A)</translation>
+        <translation type="obsolete">察看答案(&amp;A)</translation>
     </message>
     <message>
         <source>Learn ahead of schedule</source>
@@ -937,6 +957,10 @@ so you might want to run </source>
         <source>All: </source>
         <translation>所有：</translation>
     </message>
+    <message>
+        <source>Show answer</source>
+        <translation type="unfinished">察看答案</translation>
+    </message>
 </context>
 <context>
     <name>MainFrm</name>
@@ -1399,7 +1423,7 @@ Happy learning!</source>
         <source>Scheduled cards for the next days:
 
 </source>
-        <translation>今后几天計划的卡片數：
+        <translation type="obsolete">今后几天計划的卡片數：
 
 </translation>
     </message>
@@ -1423,6 +1447,40 @@ Happy learning!</source>
         <source>Grade</source>
         <translation>評分</translation>
     </message>
+    <message>
+        <source>No current card.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Grade:</source>
+        <translation type="unfinished">評分：</translation>
+    </message>
+    <message>
+        <source>Easiness:</source>
+        <translation type="unfinished">容易程度：</translation>
+    </message>
+    <message>
+        <source>Repetitions:</source>
+        <translation type="unfinished">重複次數：</translation>
+    </message>
+    <message>
+        <source>Lapses:</source>
+        <translation type="unfinished">錯過次數：</translation>
+    </message>
+    <message>
+        <source>Days since last repetition:</source>
+        <translation type="unfinished">自從上次重複的天數：</translation>
+    </message>
+    <message>
+        <source>Days until next repetition:</source>
+        <translation type="unfinished">直到下次重複的天數：</translation>
+    </message>
+    <message>
+        <source>Scheduled cards for next week:
+
+</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>StatisticsFrm</name>
@@ -1454,6 +1512,10 @@ Happy learning!</source>
         <source>&amp;OK</source>
         <translation>確認(&amp;O)</translation>
     </message>
+    <message>
+        <source>Current card</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>TipDlg</name>
